- Add schema validation for "data" and "metadata" objects
- Metadata schema refactoring, adding "plotConfiguration" key
- Implement various plot "marks" option
- Implement Log scale option in plot
- Add "plotType" key to the metadata schema
- Refactoring "scatterPlot" function
